@@ -91,6 +91,14 @@ class FormFieldBase(models.Model):
         """The default implementation returns no initial values"""
         return {}
 
+    def get_cleaners(self):
+        """
+        Return a list of ``clean()`` hooks which receive the form instance,
+        return the cleaned data and may optionally raise ``ValidationError``
+        instances.
+        """
+        return []
+
     def get_loaders(self):
         """
         Return a list of loaders
@@ -201,7 +209,10 @@ class SimpleFieldBase(FormField):
 
     choices = models.TextField(
         _("choices"),
-        help_text=_("Enter one choice per line."),
+        help_text=_(
+            "Enter one choice per line. You may optionally provide the"
+            " value and the label separated by a pipe symbol (|)."
+        ),
     )
     placeholder = models.CharField(
         _("placeholder"),
