@@ -1,10 +1,12 @@
 from itertools import chain
 
+from feincms3_forms.models import FormFieldBase
+
 
 def get_loaders(items):
     return list(
         chain.from_iterable(
-            item.get_loaders() for item in items if hasattr(item, "get_loaders")
+            item.get_loaders() for item in items if isinstance(item, FormFieldBase)
         )
     )
 
